WebSysWebGL2Surface

Struct WebSysWebGL2Surface 

pub struct WebSysWebGL2Surface {
    pub window: Window,
    pub document: Document,
    pub canvas: HtmlCanvasElement,
    /* private fields */
}
web-sys surface for WebGL2.

Fields

window: Windowdocument: Documentcanvas: HtmlCanvasElement

Implementations

Source

impl WebSysWebGL2Surface

pub fn new( canvas_name: impl AsRef<str>, ) -> Result<Self, WebSysWebGL2SurfaceError>

Create a new WebSysWebGL2Surface based on the name of the DOM canvas element named by canvas_name.

pub fn new_with_params( canvas_name: impl AsRef<str>, params: impl AsRef<JsValue>, ) -> Result<Self, WebSysWebGL2SurfaceError>

Create a new WebSysWebGL2Surface based on the name of the DOM canvas element named by canvas_name and pass along a list of parameters when creating the WebGL context.

pub fn from_canvas( window: Window, document: Document, canvas: HtmlCanvasElement, ) -> Result<Self, WebSysWebGL2SurfaceError>

Create a new WebSysWebGL2Surface based on a given HtmlCanvasElement.

pub fn from_canvas_with_params( window: Window, document: Document, canvas: HtmlCanvasElement, params: impl AsRef<JsValue>, ) -> Result<Self, WebSysWebGL2SurfaceError>

Create a new WebSysWebGL2Surface based on a given HtmlCanvasElement and pass along a list of parameters when creating the WebGL context.

pub fn back_buffer( &mut self, ) -> Result<Framebuffer<WebGL2, Dim2, (), ()>, FramebufferError>

Get the back buffer.